bayespy.nodes.SwitchingGaussianMarkovChain.set_plotter
======================================================

.. currentmodule:: bayespy.nodes

.. automethod:: SwitchingGaussianMarkovChain.set_plotter